Bot

Struct Bot 

pub struct Bot { /* private fields */ }

Implementations

Source

impl Bot

pub fn world(&self) -> &WorldMap

Read-only access to the world map.

pub fn user_id(&self) -> Option<usize>

The bot’s player id, once received from the server.

pub fn position(&self) -> Option<(usize, usize)>

The bot’s current position, once received from the server.

pub fn safe_directions(&self) -> Vec<MoveDirection>

Returns every direction whose neighbouring cell is currently empty.

pub fn is_blocked(&self, direction: MoveDirection) -> bool

True if moving in direction from the current position would hit a trail. Returns true when the position is unknown.

pub fn write_packet(&mut self, packet: ClientPacket)

Write a raw packet to the server.

pub fn chat(&mut self, message: impl Into<String>)

Send a message in chat, make sure to not get rate limited.

pub fn do_move(&mut self, direction: MoveDirection)

Set a move direction. (I think you should only do one per tick I dir not test several)